import terrylib.*;

class Main {
	var heights:Array<Int>;
	var separation : Int = 200;

	var animFrames:Int = 20;
	//tilt
	var frames0 : Array<Array<Float>>;
	var frames1 : Array<Array<Float>>;
	//tilt,leftspread,rightspread
	var playerFrames : Array<Array<Array<Array<Float>>>>;
	var carriageDat : Array<Array<Float>>;
	var playerIndex : Int;

	function new() {
		playerIndex = Std.int(peopleCount/2);
	
		poses = [LEFT,LEFT2,LEAN_LEFT,STRAIGHT,WIDE1,WIDE2,WIDE3];


		for (i in 0...poses.length){
			var pose=poses[i];
			centerPose(pose);
			scalePose(pose,0.5);
		}
//LEAN_LEFTwLEFT2, LEFT, STRAIGHT
		var EXTREMELEFT = bottomTopMerge(LEFT2,LEAN_LEFT);
		var EXTREMERIGHT = mirrorPose(EXTREMELEFT);
		var RIGHT = mirrorPose(LEFT);
		
		frames0 = new Array<Array<Float>>();
		for (i in 0...animFrames){
			var pc = i/animFrames;
			var lerp = lerpPose(EXTREMELEFT,LEFT,pc);
			frames0.push(lerp);
		}
		for (i in 0...animFrames){
			var pc = i/animFrames;
			var lerp = lerpPose(LEFT,STRAIGHT,pc);
			frames0.push(lerp);
		}
		for (i in 0...(animFrames)){
			var pc = i/animFrames;
			var lerp = lerpPose(STRAIGHT,RIGHT,pc);
			frames0.push(lerp);
		}
		for (i in 0...(animFrames+1)){
			var pc = i/animFrames;
			var lerp = lerpPose(RIGHT,EXTREMERIGHT,pc);
			frames0.push(lerp);
		}
		
		frames1 = new Array<Array<Float>>();
		for (i in 0...(animFrames+1)){
			var pc = i/animFrames;
			var lerp = lerpPose(STRAIGHT,WIDE3,pc);
			frames1.push(lerp);
		}

		playerFrames = new Array<Array<Array<Array<Float>>>>();
		for (tilt in (0)...(2*animFrames+1)){ // tilt
			var baseTilt = frames0[tilt];
			var row1 = new Array<Array<Array<Float>>>();
			for (leftSpread in 0...(animFrames+1)){
				var leftPc = leftSpread/animFrames;
				//var baseSpreadLeft = frames1[leftSpread];
				var row2 = new Array<Array<Float>>();
				for (rightSpread in 0...(animFrames+1)){
					var rightPc = rightSpread/animFrames;
					//var baseSpreadRight = frames1[leftSpread];					
					var frame = leftRightLerp(baseTilt,WIDE3,WIDE3,leftPc,rightPc);
					row2.push(frame);
				}
				row1.push(row2);				
			}
			playerFrames.push(row1);
		}

		var subdivisions : Int = 8;
		var controlPoints : Array<Int> = new Array<Int>();
		var heightCount : Int = 100;
		var offSet : Int = 0; //in pixels
		for (i in 0...heightCount){			
			var h = Random.int(carriageHeight+5,Gfx.screenheight-carriageHeight-5);
			if (i==0){
				h=Gfx.screenheightmid;	
			}
			controlPoints.push(h);
		}
		heights = new Array<Int>();
		for (i in 0...heightCount) {
			var from : Int = controlPoints[i];
			var to : Int = (i+1)<heightCount ? controlPoints[i+1] : controlPoints[0];
			for (j in 0...subdivisions){
				heights.push(interpolate(from,to,j,subdivisions));
			}
		}
		carriageDat = new Array<Array<Float>>();
		for (i in 0...3){//carriages
			for (j in 0...peopleCount){
				var p=i*peopleCount+j;
				var ar:Array<Float> = [
										Random.float(-1,1),			//0 pos
										heights[0],		//1 oldHeight
										Random.float(0.2,1.0),		//2 sensitivity
										Random.occasional()?1:0, 	//3 type
										0,							//4 leftspread
										0,							//5 rightspread
										1,							//6 forceleftshift 
										-1,							//7 forcerightshift 
										];
				carriageDat.push(ar);
			}
		}

		var playerGlobalIndex : Int = 1*peopleCount+playerIndex;

		var leftDat : Array<Float>  = carriageDat[playerGlobalIndex-1];
		var playerDat : Array<Float> = carriageDat[playerGlobalIndex];
		var rightDat : Array<Float>  = carriageDat[playerGlobalIndex+1];
		playerDat[0]=1;
		leftDat[0]=1;
		rightDat[0]=1;
		
		playerDat[2]=0.8;
		leftDat[2]=0.8;
		rightDat[2]=0.8;
	}


	function ease (t:Float) {		
		if (t < 0.5) 
			return 8*t*t*t ;
		else {
			t=1-t;
			return (1-8*t*t*t)*.5+.5;
		}
	};

	function interpolate(from:Int, to:Int, i:Float, subdivisions:Float):Int {
		var pc = i/subdivisions;
		pc = ease(pc);
		return Std.int(from*(1-pc)+to*(pc));
	}
	
	var offset=0;
	var speed=10;

	function drawTrack():Void{
		var x= -offset;

		var i=0;
		while(x+separation<0){
			i++;
			x+=separation;
		}
		i=i%heights.length;

		while(x<Gfx.screenwidth){
			var oldx=x;
			x+=separation;
			var oldHeight=heights[i%heights.length];
			var height=heights[(i+1)%heights.length];
			Gfx.drawline(oldx,oldHeight,x,height,0xffffffff);
			i++;
		}
	}

	function getHeight(globalX:Int):Int{
		var trackLength = heights.length*separation;
		globalX = (((globalX)%trackLength)+trackLength)%trackLength;
		var fromIndex = Std.int(globalX/separation);
		var toIndex = (fromIndex+1)%heights.length;
		var from=heights[fromIndex];
		var to=heights[toIndex];
		var pc = (globalX%separation)/separation;
		return Math.floor(from*(1-pc)+to*pc);
	}

	var carriageWidth = 300;
	var carriageHeight = 90;
	var carriageSeparation = 10;
	var wheelDiameter = 20;

	var peopleCount:Int=10;
	var border:Int=30;

	var leanSpeed:Float=0.02;

	function tickPerson(carriageIndex:Int, personIndex:Int, left:Float, height1:Float,height2:Float){
			var person = carriageIndex==1 && personIndex==playerIndex;
			var pose = poses[personIndex%poses.length];
			var posex = left+border+(carriageWidth-border*2)*personIndex/(peopleCount-1);
			var pc = (posex-left)/carriageWidth;
			var posey = height1+pc*(height2-height1)+40;
			
			var cd = carriageDat[carriageIndex*peopleCount+personIndex];
			var diff = posey-cd[1];		
			/*if (diff<0.1 && cd[0]>0.1){
				cd[0]
			} else {
				cd[0]=cd[0]+cd[2]*diff*leanSpeed;
			} else {
				
			}
			don't forget to remove line below:
			*/

			cd[0]=cd[0]+cd[2]*diff*leanSpeed;				
			if (cd[0]<-1){
				cd[0]=-1;
			} else if (cd[0]>1){
				cd[0]=1;
			}

			var frameIndex = Std.int(((cd[0]+1)/2)*(frames0.length-1));
			var frame = frames0[frameIndex];

			drawPose(frame,posex,posey);		

			cd[1]=posey;
	}

	
	function tickPlayer(carriageIndex:Int, personIndex:Int, left:Float, height1:Float,height2:Float){
			var person = carriageIndex==1 && personIndex==playerIndex;
			var pose = poses[personIndex%poses.length];
			var posex = left+border+(carriageWidth-border*2)*personIndex/(peopleCount-1);
			var pc = (posex-left)/carriageWidth;
			var posey = height1+pc*(height2-height1)+40;
			
			var leftDat = carriageDat[carriageIndex*peopleCount+personIndex-1];
			var rightDat = carriageDat[carriageIndex*peopleCount+personIndex+1];
			var cd = carriageDat[carriageIndex*peopleCount+personIndex];

			var diff = posey-cd[1];		
			/*if (diff<0.1 && cd[0]>0.1){
				cd[0]
			} else {
				cd[0]=cd[0]+cd[2]*diff*leanSpeed;
			} else {
				
			}
			don't forget to remove line below:
			*/
			
			if (!holding){
				cd[0]=cd[0]+cd[2]*diff*leanSpeed;				
				if (cd[0]<-1){
					cd[0]=-1;
				} else if (cd[0]>1){
					cd[0]=1;
				}	
			} else {
				if (cd[0]>0.8 && rightDat[0]<-0.8){
					cd[5]+=0.01;
					if (cd[5]>1){
						cd[5]=1;
					}
				}			
				if (cd[0]<-0.8 && leftDat[0]>0.8){
					cd[4]+=0.01;
					if (cd[4]>1){
						cd[4]=1;
					}
				}		
			}			

			var tiltIndex = Std.int(((cd[0]+1)/2)*(playerFrames.length-1));
			var tiltRow = playerFrames[tiltIndex];


			var leftLeanIndex = Std.int(cd[4]*(tiltRow.length-1));
			var leftLeanRow = tiltRow[leftLeanIndex];


			var rightLeanIndex = Std.int(cd[5]*(leftLeanRow.length-1));
			var frame = leftLeanRow[rightLeanIndex];

			var leftDone = cd[4]>=1;
			var rightDone = cd[5]>=1;
			var done = leftDone && rightDone;
			if (done){
			}

			if (leftDone){
				cd[6]-=0.01;				
				if (cd[6]<-0.5){
					cd[6]=-0.5;
				}
				if (leftDat[0]>cd[6]){
					leftDat[0]=cd[6];
				}
			}
			if (rightDone){				
				cd[7]+=0.01;
				if (cd[7]>0.5){
					cd[7]=0.5;
				}
				if (rightDat[0]<cd[7]){
					rightDat[0]=cd[7];
				}
			}

			Gfx.setcolor(0xffcccc);	
			drawPose(frame,posex,posey);		
			if (done){
				drawSmile(frame,posex,posey);
			}		
			Gfx.setcolor(0xffffff);

			cd[1]=posey;
	}


	function drawCarriage(localx:Int,carriageIndex:Int){
		var carriagex = offset+localx;
		var height1=getHeight(Std.int(carriagex-carriageWidth/2))-carriageHeight;
		var height2=getHeight(Std.int(carriagex+carriageWidth/2))-carriageHeight;

		var left = localx-carriageWidth/2;

		var wheelx1=left+carriageWidth*0.25;
		var wheely1=height1+0.25*(height2-height1)-wheelDiameter/2+carriageHeight;
		var wheelx2=left+carriageWidth*0.75;
		var wheely2=height1+0.75*(height2-height1)-wheelDiameter/2+carriageHeight;

		var playerIndex : Int = Std.int(peopleCount/2);
		if (carriageIndex==1){			
				tickPlayer(carriageIndex,playerIndex,left,height1,height2);	
		}
		for (i in 0...peopleCount){
			if (i==playerIndex&&carriageIndex==1){
				continue;		
			} else {
				tickPerson(carriageIndex,i,left,height1,height2);							
			}
		}

		height1-=wheelDiameter;
		height2-=wheelDiameter;
		Gfx.drawboxslope(left,height1,height2,carriageWidth,carriageHeight,0xffffff);


		var seatx1=left+carriageWidth*0.05;
		var seaty1=height1+0.05*(height2-height1)-wheelDiameter/2+carriageHeight;
		var seatx2=left+carriageWidth*0.95;
		var seaty2=height1+0.95*(height2-height1)-wheelDiameter/2+carriageHeight;		
		//Gfx.drawline(seatx1,seaty1,seatx2,seaty2);
		Gfx.drawline(seatx1,seaty1-16,seatx2,seaty2-16);


		height1+=Std.int(carriageHeight*0.85);
		Gfx.drawline(left,height1,left-carriageSeparation,height1);
		Gfx.drawcircle(wheelx1,wheely1,wheelDiameter/2);
		Gfx.drawcircle(wheelx2,wheely2,wheelDiameter/2);
	}

	inline static var pelvis:Int	=0*2;
	inline static var lknee:Int		=1*2;
	inline static var lankle:Int	=2*2;
	inline static var lfoot:Int		=3*2;
	inline static var rknee:Int		=4*2;
	inline static var rankle:Int	=5*2;
	inline static var rfoot:Int		=6*2;
	inline static var lshoulder:Int	=7*2;
	inline static var rshoulder:Int	=8*2;
	inline static var neck:Int		=9*2;
	inline static var lelbow:Int	=10*2;
	inline static var lhand:Int		=11*2;
	inline static var relbow:Int	=12*2;
	inline static var rhand:Int		=13*2;
	inline static var head:Int		=14*2;

var poses:Array<Array<Float>>;

var LEFT:Array<Float> = [
	881,567, //pelvis 		
	864,569, //lknee		
	871,603, //lankle		
	863,606, //lfoot		
	873,576, //rknee		
	880,604, //rankle		
	872,613, //rfoot		
	881,524, //lshoulder	
	881,524, //rshoulder	
	881,524, //neck		
	869,546, //elbowl		
	871,563, //handl		
	893,546, //elbowr		
	891,563, //handr		
	881,512 //headc		
];


var LEFT2:Array<Float> = [
		954,569 ,//pelvis		
		932,575 ,//lknee		
		947,605 ,//lankle		
		942,608 ,//lfoot		
		944,582 ,//rknee		
		963,606 ,//rankle		
		959,611 ,//rfoot		
		953,523 ,//lshoulder	
		953,523 ,//rshoulder	
		953,523 ,//neck	
		941,545 ,//elbowl	
		943,562 ,//handl	
		965,545 ,//elbowr	
		963,562 ,//handr	
		953,511
];


var LEAN_LEFT:Array<Float> = [
		 1028,562,//pelvis			
		 1018,564,//lknee		
		 1020,597,//lankle		
		 1013,605,//lfoot		
		 1039,564,//rknee		
		 1038,597,//rankle		
		 1044,606,//rfoot		
		 1013,526,//lshoulder	
		 1017,534,//rshoulder	
		 1011,521,//neck	
		 1008,554,//elbowl	
		 1008,569,//handl	
		 1029,550,//elbowr	
		 1035,570,//handr	
		 1000,520 //headc	
];



var STRAIGHT:Array<Float> = [
		 1096,564,//pelvis			
		 1088,564,//lknee		
		 1088,600,//lankle		
		 1082,603,//lfoot		
		 1104,564,//rknee		
		 1104,600,//rankle		
		 1110,603,//rfoot		
		 1096,519,//lshoulder	
		 1096,519,//rshoulder	
		 1096,519,//neck	
		 1084,544,//elbowl	
		 1086,560,//handl	
		 1108,546,//elbowr	
		 1106,560,//handr	
		 1096,509//headc	
];

var WIDE1:Array<Float> = [
		 1173,563,//pelvis			
		 1151,559,//lknee		
		 1166,598,//lankle		
		 1158,601,//lfoot		
		 1194,559,//rknee		
		 1179,598,//rankle		
		 1187,601,//rfoot		
		 1170,533,//lshoulder	
		 1176,533,//rshoulder	
		 1173,525,//neck	
		 1148,546,//elbowl	
		 1156,557,//handl	
		 1197,546,//elbowr	
		 1190,557,//handr	
		 1173,515 //headc	
];


var WIDE2:Array<Float> = [
		 1246,564,//pelvis			
		 1229,561,//lknee		
		 1224,602,//lankle		
		 1217,602,//lfoot		
		 1263,561,//rknee		
		 1268,602,//rankle		
		 1275,602,//rfoot		
		 1243,534,//lshoulder	
		 1249,534,//rshoulder	
		 1246,527,//neck	
		 1222,547,//elbowl	
		 1229,558,//handl	
		 1270,547,//elbowr	
		 1263,558,//handr	
		 1246,516 //headc	
];


var WIDE3:Array<Float> = [
		 1336,562,//pelvis			
		 1313,573,//lknee		
		 1299,601,//lankle		
		 1292,600,//lfoot		
		 1359,573,//rknee		
		 1373,601,//rankle		
		 1380,600,//rfoot		
		 1332,540,//lshoulder	
		 1340,540,//rshoulder	
		 1336,532,//neck	
		 1309,528,//lelbow
		 1326,524,//lhand	
		 1363,528,//relbow
		 1346,524,//rhand
		 1336,521//head
];
	
	private static inline function Lerp(a:Float,b:Float,pc:Float){
		return a*(1-pc)+b*pc;
	}

	function leftRightLerp(base:Array<Float>,left:Array<Float>,right:Array<Float>,pcLeft:Float,pcRight:Float) : Array<Float>{
		var result = base.copy();

		result[rknee] 	= Lerp(		result[rknee],		right[rknee],		pcRight);
		result[rankle] 	= Lerp(		result[rankle],		right[rankle],		pcRight);
		result[rfoot] 	= Lerp(		result[rfoot],		right[rfoot],		pcRight);
		result[rshoulder] = Lerp(	result[rshoulder],	right[rshoulder],	pcRight);
		result[relbow] 	= Lerp(		result[relbow],		right[relbow],		pcRight);
		result[rhand] 	= Lerp(		result[rhand],		right[rhand],		pcRight);

		result[lknee] 	= Lerp(		result[lknee],		left[lknee],		pcLeft);
		result[lankle] 	= Lerp(		result[lankle],		left[lankle],		pcLeft);
		result[lfoot] 	= Lerp(		result[lfoot],		left[lfoot],		pcLeft);
		result[lshoulder] = Lerp(	result[lshoulder],	left[lshoulder],	pcLeft);
		result[lelbow] 	= Lerp(		result[lelbow],		left[lelbow],		pcLeft);
		result[lhand] 	= Lerp(		result[lhand],		left[lhand],		pcLeft);

		result[neck] 	= Lerp(result[neck],(left[neck]+right[neck])/2,(pcLeft+pcRight)/2);
		result[head] 	= Lerp(result[head],(left[head]+right[head])/2,(pcLeft+pcRight)/2);

		result[rknee+1] 	= Lerp(		result[rknee+1],		right[rknee+1],		pcRight);
		result[rankle+1] 	= Lerp(		result[rankle+1],		right[rankle+1],		pcRight);
		result[rfoot+1] 	= Lerp(		result[rfoot+1],		right[rfoot+1],		pcRight);
		result[rshoulder+1] = Lerp(	result[rshoulder+1],	right[rshoulder+1],	pcRight);
		result[relbow+1] 	= Lerp(		result[relbow+1],		right[relbow+1],		pcRight);
		result[rhand+1] 	= Lerp(		result[rhand+1],		right[rhand+1],		pcRight);

		result[lknee+1] 	= Lerp(		result[lknee+1],		left[lknee+1],		pcLeft);
		result[lankle+1] 	= Lerp(		result[lankle+1],		left[lankle+1],		pcLeft);
		result[lfoot+1] 	= Lerp(		result[lfoot+1],		left[lfoot+1],		pcLeft);
		result[lshoulder+1] = Lerp(	result[lshoulder+1],	left[lshoulder+1],	pcLeft);
		result[lelbow+1] 	= Lerp(		result[lelbow+1],		left[lelbow+1],		pcLeft);
		result[lhand+1] 	= Lerp(		result[lhand+1],		left[lhand+1],		pcLeft);

		result[neck+1] 	= Lerp(result[neck+1],(left[neck+1]+right[neck+1])/2,(pcLeft+pcRight)/2);
		result[head+1] 	= Lerp(result[head+1],(left[head+1]+right[head+1])/2,(pcLeft+pcRight)/2);

		return result;
	}

	function leftRightMerge(left:Array<Float>,right:Array<Float>){
		var result = left.copy();

		result[rknee] = right[rknee];
		result[rankle] = right[rankle];
		result[rfoot] = right[rfoot];
		result[rshoulder] = right[rshoulder];
		result[relbow] = right[relbow];
		result[rhand] = right[rhand];
		result[neck] = (result[neck]+right[neck])/2;
		result[head] = (result[head]+right[head])/2;

		result[rknee+1] = right[rknee+1];
		result[rankle+1] = right[rankle+1];
		result[rfoot+1] = right[rfoot+1];
		result[rshoulder+1] = right[rshoulder+1];
		result[relbow+1] = right[relbow+1];
		result[rhand+1] = right[rhand+1];
		result[neck+1] = (result[neck+1]+right[neck+1])/2;
		result[head+1] = (result[head+1]+right[head+1])/2;

		return result;
	}
	function bottomTopMerge(bottom:Array<Float>,top:Array<Float>){
		var result = bottom.copy();

		result[lshoulder] 	= top[lshoulder];
		result[rshoulder] 	= top[rshoulder];
		result[neck]		= top[neck];
		result[lelbow]		= top[lelbow];
		result[lhand]		= top[lhand];
		result[relbow]		= top[relbow];
		result[rhand]		= top[rhand];
		result[head]		= top[head];

		result[lshoulder+1] 	= top[lshoulder+1];
		result[rshoulder+1] 	= top[rshoulder+1];
		result[neck+1]			= top[neck+1];
		result[lelbow+1]		= top[lelbow+1];
		result[lhand+1]			= top[lhand+1];
		result[relbow+1]		= top[relbow+1];
		result[rhand+1]			= top[rhand+1];
		result[head+1]			= top[head+1];

		return result;
	}

	function mirrorPose(pose:Array<Float>){
		var result : Array<Float> = pose.copy();
		result[pelvis]		= -pose[pelvis];
		result[lknee]		= -pose[rknee];
		result[lankle]		= -pose[rankle];
		result[lfoot]		= -pose[rfoot];
		result[rknee]		= -pose[lknee];
		result[rankle]		= -pose[lankle];
		result[rfoot]		= -pose[lfoot];
		result[lshoulder] 	= -pose[rshoulder];
		result[rshoulder] 	= -pose[lshoulder];
		result[neck]		= -pose[neck];
		result[lelbow]		= -pose[relbow];
		result[lhand]		= -pose[rhand];
		result[relbow]		= -pose[lelbow];
		result[rhand]		= -pose[lhand];
		result[head]		= -pose[head];
		return result;
	}

	function lerpPose(pose1:Array<Float>,pose2:Array<Float>,t:Float) {
		var r = new Array<Float>();
		for (i in 0...pose1.length){
			var a = pose1[i]; 
			var b = pose2[i];
			var v = a*(1-t)+b*t;
			r.push(v);
		}		
		return r;
	}
	function scalePose(pose:Array<Float>,scaleFactor:Float){
		for (i in 0...pose.length){
			pose[i]*=scaleFactor;
		}
	}
	function centerPose(pose:Array<Float>){
		for (i in 1...15){		
			pose[2*i]-=pose[0*i];
			pose[2*i+1]-=pose[0*i+1];
		}
		pose[0]=0;
		pose[1]=0;
	}
	
	function drawPose(pose:Array<Float>,x:Float,y:Float){		
		Gfx.drawline(	x+pose[lfoot],		y+pose[lfoot+1],		x+pose[lankle],		y+pose[lankle+1]);
		Gfx.drawline(	x+pose[lankle],		y+pose[lankle+1],		x+pose[lknee],		y+pose[lknee+1]);
		Gfx.drawline(	x+pose[lknee],		y+pose[lknee+1],		x+pose[pelvis],		y+pose[pelvis+1]);
		Gfx.drawline(	x+pose[rfoot],		y+pose[rfoot+1],		x+pose[rankle],		y+pose[rankle+1]);
		Gfx.drawline(	x+pose[rankle],		y+pose[rankle+1],		x+pose[rknee],		y+pose[rknee+1]);
		Gfx.drawline(	x+pose[rknee],		y+pose[rknee+1],		x+pose[pelvis],		y+pose[pelvis+1]);
		Gfx.drawline(	x+pose[pelvis],		y+pose[pelvis+1],		x+pose[neck],			y+pose[neck+1]);
		Gfx.drawline(	x+pose[lshoulder],	y+pose[lshoulder+1],	x+pose[lelbow],		y+pose[lelbow+1]);
		Gfx.drawline(	x+pose[lelbow],		y+pose[lelbow+1],		x+pose[lhand],		y+pose[lhand+1]);
		Gfx.drawline(	x+pose[rshoulder],	y+pose[rshoulder+1],	x+pose[relbow],		y+pose[relbow+1]);
		Gfx.drawline(	x+pose[relbow],		y+pose[relbow+1],		x+pose[rhand],		y+pose[rhand+1]);
		Gfx.drawcircle(	x+pose[head],		y+pose[head+1],			5);
	}

	function drawSmile(pose:Array<Float>,x:Float,y:Float){	
		Gfx.setthickness(1.0);
		Gfx.drawcircle(	x+pose[head]-3,		y+pose[head+1]-1,			1);	
		Gfx.drawcircle(	x+pose[head]+3,		y+pose[head+1]-1,			1);	
		Gfx.drawline(x+pose[head]-3,y+pose[head+1]+2,x+pose[head]+3,y+pose[head+1]+2);
		Gfx.setthickness(1.5);
		
	}

	private var holding:Bool=false;

	private var started:Bool=false;
	function update() {
		if (started==false){
			Text.display(Gfx.CENTER,100,"CARRIAGE GAME");
			Text.display(Gfx.CENTER,150,"controls: click to brace");
			Text.display(Gfx.CENTER,300,"click to begin");

			if (Mouse.leftclick()){
				started=true;
			}
			return;
		}
		
		if (Mouse.leftclick()){
			holding=true;
		}
		if(Mouse.leftreleased()){
			holding=false;
		}
		//if (Input.pressed(Key.RIGHT)){
			
		//}
		offset+=speed;

		Gfx.startdraw();
		drawTrack();
		drawCarriage(Gfx.screenwidthmid-(carriageWidth+carriageSeparation),0);
		drawCarriage(Gfx.screenwidthmid,1);
		drawCarriage(Gfx.screenwidthmid+carriageWidth+carriageSeparation,2);

		//drawPose(LEFT,Gfx.screenwidthmid,Gfx.screenheightmid);

/*
		for (i in 0...poses.length){
			var pose=poses[i];
			drawPose(pose,100+i*50,Gfx.screenheightmid);
		}*/

		Gfx.enddraw();
	}
	
	
}
